@@ -8,17 +8,29 @@ use 5.14.2;
 use DBI qw(:utils);
 use JSON::PP;
 use Digest::MD5 qw(md5_hex);
+use Log::Any qw( $log );
 
 use Zonemaster::Backend::Config;
 
 with 'Zonemaster::Backend::DB';
 
-my $connection_string = Zonemaster::Backend::Config->DB_connection_string( 'sqlite' );
+my $connection_string = Zonemaster::Backend::Config->load_config()->DB_connection_string( 'sqlite' );
 
 has 'dbh' => (
     is      => 'ro',
     isa     => 'DBI::db',
-    default => sub { DBI->connect( $connection_string, { RaiseError => 1, AutoCommit => 1 } ) },
+    default => sub {
+        $log->debug( "Connection string: " . $connection_string );
+        my $dbh = DBI->connect(
+            $connection_string,
+            {
+                AutoCommit => 1,
+                RaiseError => 1,
+            }
+        ) or die $DBI::errstr;
+        $log->debug( "Database filename: " . $dbh->sqlite_db_filename );
+        $dbh
+    },
 );
 
 sub DEMOLISH {
@@ -235,11 +247,7 @@ sub get_test_history {
     my @results;
 
     my $undelegated = "";
-    if ($p->{filter} eq "old_behavior" ) {
-        $undelegated = (defined $p->{frontend_params}->{nameservers})
-            ? ("AND (params->'nameservers') IS NOT NULL")
-            : ("AND (params->'nameservers') IS NULL");
-    } elsif ($p->{filter} eq "undelegated") {
+    if ($p->{filter} eq "undelegated") {
         $undelegated = "AND (params->'nameservers') IS NOT NULL";
     } elsif ($p->{filter} eq "delegated") {
         $undelegated = "AND (params->'nameservers') IS NULL";
@@ -261,7 +269,7 @@ sub get_test_history {
     $sth1->execute;
     while ( my $h = $sth1->fetchrow_hashref ) {
         push( @results,
-            { id => $h->{id}, creation_time => $h->{creation_time}, advanced_options => $h->{advanced_options} } );
+            { id => $h->{id}, creation_time => $h->{creation_time} } );
     }
     $sth1->finish;
 
