@@ -20,23 +20,26 @@ unset LC_MESSAGES
 unset LC_ALL
 export LC_CTYPE="en_US.UTF-8"
 
-LOGDIR=/var/log/zonemaster
-PIDDIR=/var/run/zonemaster
-LISTENIP=127.0.0.1
-USER=zonemaster
-GROUP=zonemaster
+BASEDIR=${ZM_BACKEND_BASEDIR:-/usr/local}
+LOGDIR=${ZM_BACKEND_LOGDIR:-/var/log/zonemaster}
+PIDDIR=${ZM_BACKEND_PIDDIR:-/var/run/zonemaster}
+LISTENIP=${ZM_BACKEND_LISTENIP:-127.0.0.1}
+USER=${ZM_BACKEND_USER:-zonemaster}
+GROUP=${ZM_BACKEND_GROUP:-zonemaster}
 
 STARMAN=`PATH="$PATH:/usr/local/bin" /usr/bin/which starman`
 
+testagent_args="--logfile=$LOGDIR/zonemaster_backend_testagent.log --user=$USER --group=$GROUP --pidfile=$PIDDIR/zonemaster_backend_testagent.pid"
+
 start() {
-    $STARMAN --user=$USER --group=$GROUP --error-log=$LOGDIR/zm-starman-error.log --pid=$PIDDIR/zm-starman.pid --listen=$LISTENIP:5000 --daemonize /usr/local/bin/zonemaster_backend_rpcapi.psgi
-    /usr/local/bin/zonemaster_backend_testagent --user=$USER --group=$GROUP --pidfile=$PIDDIR/zonemaster_backend_testagent.pid start
+    $STARMAN --user=$USER --group=$GROUP --error-log=$LOGDIR/zm-starman-error.log --pid=$PIDDIR/zm-starman.pid --listen=$LISTENIP:5000 --daemonize $BASEDIR/bin/zonemaster_backend_rpcapi.psgi
+    $BASEDIR/bin/zonemaster_backend_testagent $testagent_args start
 }
 
 stop() {
     if [ -f $PIDDIR/zonemaster_backend_testagent.pid ]
     then
-        /usr/local/bin/zonemaster_backend_testagent --user=$USER --group=$GROUP --pidfile=$PIDDIR/zonemaster_backend_testagent.pid stop
+        $BASEDIR/bin/zonemaster_backend_testagent $testagent_args stop
     fi
 
     if [ -f $PIDDIR/zm-starman.pid ]
